#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_PRINTING
#undef HAVE_PTHREADS
#undef ksize_t
#undef HAVE_GTKHTML
#undef USE_GTKEXTEXT
#undef HAVE_GUILE
#undef USE_GCONF
#undef HAVE_GNOME_VFS
#define I_LIKE_WASTING_RESOURCES 0
